@@ -14,7 +14,6 @@
 #    under the License.
 
 import collections
-import contextlib
 import socket
 
 import mock
@@ -159,11 +158,9 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                            'hrsp_3xx,hrsp_4xx,hrsp_5xx,hrsp_other,hanafail,'
                            'req_rate,req_rate_max,req_tot,cli_abrt,srv_abrt,'
                            '\n')
-        with contextlib.nested(
-                mock.patch.object(self.driver, '_get_state_file_path'),
-                mock.patch('socket.socket'),
-                mock.patch('os.path.exists'),
-        ) as (gsp, mocket, path_exists):
+        with mock.patch.object(self.driver, '_get_state_file_path') as gsp, \
+                mock.patch('socket.socket') as mocket, \
+                mock.patch('os.path.exists') as path_exists:
             gsp.side_effect = lambda x, y, z: '/pool/' + y
             path_exists.return_value = True
             mocket.return_value = mocket
@@ -410,8 +407,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                                                        namespace='ns1')
 
     @mock.patch('neutron.common.utils.ensure_dir')
-    @mock.patch('neutron_lbaas.services.loadbalancer.drivers.haproxy.'
-                'jinja_cfg.save_config')
+    @mock.patch('neutron_lbaas.drivers.haproxy.jinja_cfg.save_config')
     @mock.patch('neutron.agent.linux.ip_lib.IPWrapper')
     def test_spawn(self, ip_wrap, jinja_save, ensure_dir):
         mock_ns = ip_wrap.return_value
@@ -574,7 +570,8 @@ class TestListenerManager(BaseTestListenerManager):
         self.driver.reset_mock()
         self.listener_manager.delete(self.listener2)
         self.assertFalse(self.refresh.called)
-        self.driver.undeploy_instance.assert_called_once_with(self.in_lb.id)
+        self.driver.undeploy_instance.assert_called_once_with(
+            self.in_lb.id, delete_namespace=True)
 
 
 class BaseTestPoolManager(BaseTestListenerManager):
